@@ -626,6 +626,10 @@ liq_crash_if_invalid_handle_pointer_given(const liq_attr *user_supplied_pointer,
     }
 
     if (user_supplied_pointer->magic_header == liq_freed_magic) {
+	fprintf (stderr, "%s\n", maniac);
+	fprintf (stderr, "pointers ---> %p %p %p %p\n",
+		 user_supplied_pointer, user_supplied_pointer->magic_header,
+		 liq_attr_magic, liq_freed_magic);
 	return LIQ_FREED_POINTER;
     }
 
@@ -855,8 +859,6 @@ liq_error liq_set_log_flush_callback(liq_attr *attr, liq_log_flush_callback_func
 
 static void *liq_aligned_malloc(size_t size)
 {
-    return malloc (size);
-    /*
     unsigned char *ptr = malloc(size + 16);
     if (!ptr) {
         return NULL;
@@ -867,18 +869,14 @@ static void *liq_aligned_malloc(size_t size)
     assert(0 == (((uintptr_t)ptr) & 15));
     ptr[-1] = offset ^ 0x59; // store how much pointer was shifted to get the original for free()
     return ptr;
-    */
 }
 
 static void liq_aligned_free(void *inptr)
 {
-    /*
     unsigned char *ptr = inptr;
     size_t offset = ptr[-1] ^ 0x59;
     assert(offset > 0 && offset <= 16);
     free(ptr - offset);
-    */
-    free (inptr);
 }
 
 liq_attr* liq_attr_create_with_allocator(void* (*custom_malloc)(size_t), void (*custom_free)(void*))
